library(lattice)
library(SVGAnnotation)
data(mtcars)
doc = svgPlot(xyplot(mpg ~ wt, mtcars, groups = cyl, auto.key = TRUE))
getNodeSet(doc, "//r:legend", c("r" = "http://www.r-project.org"))


mtcars$cyl = factor(mtcars$cyl)
gearLabels = sprintf("%d gears", unique(mtcars$gear))
gearGroups = sort(unique(mtcars$gear))
counts = table(mtcars$am, mtcars$gear)

doc = svgPlot({vv <- xyplot(mpg ~ disp| am, groups = cyl, data = mtcars,
                            legend = list(top = list(fun = draw.key,
                                                      args = list(key = list(text = list(gearLabels), columns = 3))
                                                     ),
                                          bottom = list(fun = draw.key,
                                                         args = list(key = list(text = list(levels(mtcars$cyl)),                       
                                                                                points = list(pch = 21,
                                                                                              col = trellis.par.get("superpose.symbol")$col[seq(along = levels(mtcars$cyl))]),
                                                                                 columns = 3))
                                                       )
                                  ))})

legends = getNodeSet(doc, "//r:legend", c("r" = "http://www.r-project.org"))

nodes = getLatticeLegendNodes(doc, panels, 1)
sapply(seq(along = 1:length(gearGroups)), 
       function(i) {
        cts = paste("[", paste(counts[,i], collapse = ", "), "]", sep = "")
        addAttributes(nodes[[i]], 
          onmouseover = paste("highlight(", gearGroups[i], ",", 
                              cts, ", true)"),
          onmouseout = paste("highlight(", gearGroups[i], ",", 
                              cts, ", false)")
        )
       }
      )

jscript = list.files(system.file("examples", "Javascript", 
                       package="SVGAnnotation"), 
                     full.names = TRUE, pattern = "multiLegend")
addECMAScripts(doc, jscript)

saveXML(doc, "mt_lattice.svg")

